:gitlab_url: https://gitlab.kitware.com/computer-vision/geowatch

.. The large version wont work because github strips rst image rescaling. https://i.imgur.com/AcWVroL.png
    # TODO: Add a logo
    .. image:: https://i.imgur.com/PoYIsWE.png
       :height: 100px
       :align: left

Welcome to geowatch's documentation!
====================================

.. The __init__ files contains the top-level documentation overview
.. automodule:: geowatch.__init__
   :show-inheritance:

.. toctree::
   :maxdepth: 5

   auto/modules.rst
   manual/manual

See Also:

  + `Onboarding <manual/onboarding.rst>`_

  + `Contribution Instructions <manual/development/contribution_instructions.rst>`_

  + `Rebasing Procedure <manual/development/rebasing_procedure.rst>`_

  + `Testing Practices <manual/testing/testing_practices.rst>`_

  + `Coding Conventions <manual/development/coding_conventions.rst>`_

  + `Supporting Projects <manual/misc/supporting_projects.rst>`_


Manual Docs:

* `algorithms/fusion_overview <manual/algorithms/fusion_overview.rst>`_

* `algorithms/sensorchan_specs <manual/algorithms/sensorchan_specs.rst>`_

* `algorithms/ta2_deep_dive_info <manual/algorithms/ta2_deep_dive_info.md>`_

* `baselines/baseline-2023-06-22-bas <manual/baselines/baseline-2023-06-22-bas.rst>`_

* `baselines/baseline-2023-06-22-joint_bas_sc <manual/baselines/baseline-2023-06-22-joint_bas_sc.rst>`_

* `baselines/baseline-2023-06-22-sc_truth <manual/baselines/baseline-2023-06-22-sc_truth.rst>`_

* `baselines/baseline-2023-10-12-full <manual/baselines/baseline-2023-10-12-full.rst>`_

* `baselines/variation-2023-11-14-full <manual/baselines/variation-2023-11-14-full.rst>`_

* `data/access_dvc_repos <manual/data/access_dvc_repos.rst>`_

* `data/internal_resources <manual/data/internal_resources.rst>`_

* `data/using_geowatch_dvc <manual/data/using_geowatch_dvc.rst>`_

* `debugging/debugging_cmdqueue <manual/debugging/debugging_cmdqueue.rst>`_

* `development/coding_conventions <manual/development/coding_conventions.rst>`_

* `development/coding_tips <manual/development/coding_tips.rst>`_

* `development/contributing_new_models <manual/development/contributing_new_models.rst>`_

* `development/contribution_instructions <manual/development/contribution_instructions.rst>`_

* `development/rebasing_procedure <manual/development/rebasing_procedure.rst>`_

* `development/ta2_feature_integration <manual/development/ta2_feature_integration.md>`_

* `environment/getting_started_aws <manual/environment/getting_started_aws.rst>`_

* `environment/getting_started_dvc <manual/environment/getting_started_dvc.rst>`_

* `environment/getting_started_kubectl <manual/environment/getting_started_kubectl.rst>`_

* `environment/getting_started_ssh_keys <manual/environment/getting_started_ssh_keys.rst>`_

* `environment/install_python <manual/environment/install_python.rst>`_

* `environment/install_python_conda <manual/environment/install_python_conda.rst>`_

* `environment/install_python_pyenv <manual/environment/install_python_pyenv.rst>`_

* `environment/installing_geowatch <manual/environment/installing_geowatch.rst>`_

* `environment/understanding_editable_installs <manual/environment/understanding_editable_installs.rst>`_

* `environment/windows <manual/environment/windows.rst>`_

* `faq/model_prediction <manual/faq/model_prediction.rst>`_

* `faq/stac <manual/faq/stac.rst>`_

* `misc/structure_proposal <manual/misc/structure_proposal.md>`_

* `misc/supporting_projects <manual/misc/supporting_projects.rst>`_

* `mlops <manual/mlops.md>`_

* `onboarding <manual/onboarding.rst>`_

* `smart/smart_ac_tutorial <manual/smart/smart_ac_tutorial.rst>`_

* `smart/smart_ensemble_tutorial <manual/smart/smart_ensemble_tutorial.rst>`_

* `smartflow/getting_started_smartflow <manual/smartflow/getting_started_smartflow.rst>`_

* `smartflow/smartflow_copying_large_files_to_efs <manual/smartflow/smartflow_copying_large_files_to_efs.md>`_

* `smartflow/smartflow_running_the_system <manual/smartflow/smartflow_running_the_system.rst>`_

* `smartflow/smartflow_training_fusion_models <manual/smartflow/smartflow_training_fusion_models.md>`_

* `testing/running_ci_locally <manual/testing/running_ci_locally.rst>`_

* `testing/testing_practices <manual/testing/testing_practices.rst>`_

* `watch_cli <manual/watch_cli.rst>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
